NetworkCall<T> class

Constructors

NetworkCall()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

getter/setter pair

Static Methods

networkCall<T>({required Future<T?> future(), dynamic onComplete(T?)?, bool isInternetCheckEnabled = false, bool isAutoCloseKeyboard = false, dynamic onError(Object error, StackTrace stackTrace)?}) Future<void>
setNavigatorKey(GlobalKey<NavigatorState> key) → void