CloseButtonShowType enum
Defines the visibility behavior of the toast close button.
This enum provides three different modes for controlling when the close button should be visible in the toast notification.
Values
- always → const CloseButtonShowType
-
Shows the close button at all times
const CloseButtonShowType._('Always') - onHover → const CloseButtonShowType
-
Shows the close button only when the mouse hovers over the toast
const CloseButtonShowType._('On Hover') - none → const CloseButtonShowType
-
Never shows the close button
const CloseButtonShowType._('None')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
toValueString(
) → String
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CloseButtonShowType> - A constant List of the values in this enum, in order of their declaration.