DefaultStyleValues class
- Inheritance
-
- Object
- StandardStyleValues
- DefaultStyleValues
Constructors
-
DefaultStyleValues({required MaterialColor primaryColor, required Color surfaceLight, required Color surfaceDark, EdgeInsetsGeometry padding = const EdgeInsetsDirectional.fromSTEB(20, 16, 12, 16), BorderSide borderSide = const BorderSide(color: Colors.black12), BorderRadiusGeometry borderRadius = const BorderRadius.all(Radius.circular(12)), List<
BoxShadow> boxShadow = const [], int titleMaxLines = 2, int descriptionMaxLines = 6, double progressIndicatorStrokeWidth = 2.0, BoxConstraints constraints = const BoxConstraints(minHeight: 64.0)}) -
const
Properties
- borderRadius → BorderRadiusGeometry
-
no setteroverride
- borderSide → BorderSide
-
no setteroverride
-
boxShadow
→ List<
BoxShadow> -
no setteroverride
- constraints → BoxConstraints
-
no setteroverride
- descriptionMaxLines → int
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- padding → EdgeInsetsGeometry
-
no setteroverride
- primaryColor → MaterialColor
-
no setteroverride
- progressIndicatorStrokeWidth → double
-
no setteroverride
- progressIndicatorTheme → ProgressIndicatorThemeData?
-
finalinherited
-
props
→ List<
Object> -
The list of properties that will be used to determine whether
two instances are equal.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool
-
If set to
true, the toString method will be overridden to output this instance's props.no setterinherited - surfaceDark → Color
-
no setteroverride
- surfaceLight → Color
-
no setteroverride
- titleMaxLines → int
-
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited